@@ -1,8 +1,9 @@
-context("ggeffects, linear model")
+stopifnot(require("testthat"),
+          require("ggeffects"),
+          require("sjlabelled"),
+          require("sjmisc"))
 
-library(ggeffects)
-library(sjmisc)
-library(sjlabelled)
+context("ggeffects, linear model")
 
 # lm, linear regression ----
 
@@ -37,11 +38,6 @@ test_that("ggpredict, lm, condition", {
   ggpredict(fit, c("c172code", "c161sex"), condition = c(c12hour = 40), ci.lvl = .8, typical = "median", x.as.factor = TRUE)
 })
 
-test_that("ggpredict, lm, condition", {
-  ggpredict(fit, "c172code", condition = c(c12hour = 40), ci.lvl = .8, typical = "median", x.as.factor = TRUE, pretty = FALSE)
-  ggpredict(fit, c("c172code", "c161sex"), condition = c(c12hour = 40), ci.lvl = .8, typical = "median", x.as.factor = TRUE, pretty = FALSE)
-})
-
 test_that("ggpredict, lm, pretty", {
   ggpredict(fit, "c12hour", full.data = TRUE, ci.lvl = .8, typical = "median", x.as.factor = TRUE)
   ggpredict(fit, c("c12hour", "c161sex"), full.data = TRUE, ci.lvl = .8, typical = "median", x.as.factor = TRUE)
@@ -58,13 +54,6 @@ test_that("ggaverage, lm", {
   ggaverage(fit, c("c12hour", "c161sex", "c172code"))
 })
 
-test_that("ggalleffects, lm", {
-  ggalleffects(fit, "c12hour")
-  ggalleffects(fit, c("c12hour", "c161sex"))
-  ggalleffects(fit, c("c12hour", "c161sex", "c172code"))
-  ggalleffects(fit)
-})
-
 test_that("ggeffect, lm", {
   ggeffect(fit, "c12hour")
   ggeffect(fit, c("c12hour", "c161sex"))
@@ -90,6 +79,21 @@ test_that("ggpredict, lm", {
 })
 
 
+test_that("ggeffect, lm", {
+  ggeffect(fit, "c12hour [20,30,40]")
+  ggeffect(fit, "c12hour [30:60]")
+  ggeffect(fit, c("c12hour  [30:60]", "c161sex", "c172code [high level of education,low level of education]"))
+})
+
+test_that("ggeffect, lm", {
+  ggeffect(fit, "c12hour [meansd]")
+  ggeffect(fit, "c12hour [minmax]")
+  ggeffect(fit, c("c12hour [quart]", "c161sex", "c172code [high level of education,low level of education]"))
+  ggeffect(fit, c("c12hour [zeromax]", "c161sex", "c172code [high level of education,low level of education]"))
+  ggeffect(fit, c("c12hour [quart2]", "c161sex", "c172code [high level of education,low level of education]"))
+})
+
+
 data(efc)
 efc$c172code <- to_label(efc$c172code)
 fit <- lm(barthtot ~ log(c12hour) + c161sex + c172code, data = efc)
@@ -100,3 +104,11 @@ test_that("ggpredict, lm, log", {
   ggpredict(fit, c("c12hour", "c172code [high level of education,low level of education]"))
   ggpredict(fit, c("c12hour [exp]", "c172code [high level of education,low level of education]"))
 })
+
+
+test_that("ggeffect, lm, log", {
+  ggeffect(fit, "c12hour [meansd]")
+  ggeffect(fit, "c12hour [minmax]")
+  ggeffect(fit, c("c12hour", "c172code [high level of education,low level of education]"))
+  ggeffect(fit, c("c12hour [exp]", "c172code [high level of education,low level of education]"))
+})
