@@ -1,13 +1,13 @@
+stopifnot(require("testthat"),
+          require("ggeffects"),
+          require("nlme"),
+          require("sjlabelled"),
+          require("sjmisc"))
+
 context("ggeffects, lme")
 
-library(ggeffects)
-library(sjmisc)
-library(sjlabelled)
-
-
 # lme ----
 
-library(nlme)
 fit <- lme(distance ~ age + Sex, data = Orthodont, random = ~ 1)
 
 test_that("ggpredict, lme", {
@@ -22,19 +22,12 @@ test_that("ggaverage, lme", {
   ggaverage(fit, c("age", "Sex"))
 })
 
-test_that("ggalleffects, lme", {
-  ggalleffects(fit, "age")
-  ggalleffects(fit, c("age", "Sex"))
-  ggalleffects(fit)
-})
-
 test_that("ggeffect, lme", {
   ggeffect(fit, "age")
   ggeffect(fit, c("age", "Sex"))
 })
 
 
-library(nlme)
 data(Orthodont)
 
 m5 <- lmer(distance ~ age * Sex + (age|Subject), data = Orthodont)
