@@ -1,10 +1,8 @@
+stopifnot(require("testthat"),
+          require("ggeffects"))
+
 context("ggeffects, poisson model")
 
-library(ggeffects)
-library(sjmisc)
-library(sjlabelled)
-
-
 # glm, poisson regression ----
 data(efc)
 fit <- glm(tot_sc_e ~ neg_c_7 + c12hour + e42dep + c161sex + c172code, data = efc, family = poisson(link = "log"))
@@ -21,13 +19,6 @@ test_that("ggaverage, glm", {
   ggaverage(fit, c("c12hour", "c161sex", "c172code"))
 })
 
-test_that("ggalleffects, glm", {
-  ggalleffects(fit, "c12hour")
-  ggalleffects(fit, c("c12hour", "c161sex"))
-  ggalleffects(fit, c("c12hour", "c161sex", "c172code"))
-  ggalleffects(fit)
-})
-
 test_that("ggeffect, glm", {
   ggeffect(fit, "c12hour")
   ggeffect(fit, c("c12hour", "c161sex"))
